@@ -1,17 +1,17 @@
 import logging
 
-from skippy.data.minio import upload_file, download_file
+from skippy.data.minio import upload_file, download_files
 
 
-def consume(urn):
+def consume(urns=None):
     def wrapper(func):
         logging.info('Consume.wrapper(%s)' % func)
 
         def call(*args, **kwargs):
             logging.info('Consume.call(%s,%s,%s)' % (func, args, kwargs))
-            content = download_file(urn)
-            logging.info('Content Data(%s)' % content)
-            kwargs['data'] = content
+            artifact = download_files(urns)
+            logging.info('Content Data(%s)' % artifact)
+            kwargs['data'] = artifact
             return func(*args, **kwargs)
 
         logging.debug('Consume.wrapper over')
@@ -20,14 +20,14 @@ def consume(urn):
     return wrapper
 
 
-def produce(urn):
+def produce(urn=None):
     def wrapper(func):
         logging.info('Produce.wrapper(%s)' % func)
 
         def call(*args, **kwargs):
             logging.info('Produce.call(%s,%s,%s)' % (func, args, kwargs))
             response = func(*args, **kwargs)
-            upload_file(urn,response)
+            upload_file(response, urn)
             logging.info('Produce.store(%s)' % response)
             return response
 
@@ -35,3 +35,5 @@ def produce(urn):
         return call
 
     return wrapper
+
+
