@@ -1,37 +1,19 @@
 import os
 import logging
 from collections import defaultdict
-from typing import List, Dict
 
-from kubernetes import client, config
 from minio import Minio
 from minio.error import ResponseError
 
 from skippy.data import utils
 from skippy.data.priorities import get_best_node
+from skippy.data.redis import list_stoarage_pods_node
 from skippy.data.utils import get_bucket_urn, get_file_name_urn
 
 _CONSUME_LABEL = 'data.consume'
 __PRODUCE_LABEL = 'data.produce'
 
 
-def list_minio_pods_node(node: str) -> List[str]:
-    logging.debug('list minio pods...')
-    # Load the configuration when running inside the cluster (by reading envs set by k8s)
-    #config.load_kube_config()
-    logging.debug('Loading in-cluster config...')
-    config.load_incluster_config()
-    api = client.CoreV1Api()
-    # field selectors are a string, you need to parse the fields from the pods here
-    app = 'minio'
-    field_selector = 'spec.nodeName=' + node if node else None
-    ret = api.list_namespaced_pod(watch=False, namespace="default", label_selector="app=" + app,
-                                  field_selector=field_selector)
-    for i in ret.items:
-        for c in filter(lambda co: co.name == app, i.spec.containers):
-            return ['{}:{}'.format(i.status.pod_ip, p.container_port) for p in c.ports]
-
-
 def has_pod_file(urn: str, minio_addr: str) -> bool:
     try:
         if has_pod_bucket(get_bucket_urn(urn), minio_addr):
@@ -78,7 +60,7 @@ def download_file(urn: str) -> str:
     # where do we make this decisison
     # find the best pod to download
     best_storage = get_best_node(urn)
-    for minio_addr in list_minio_pods_node(best_storage):
+    for minio_addr in list_stoarage_pods_node(best_storage):
         if has_pod_file(urn, minio_addr):
             client = minio_client(minio_addr)
             response = client.get_object(get_bucket_urn(urn), get_file_name_urn(urn))
@@ -97,7 +79,7 @@ def upload_file(content: str, urn: str) -> None:
     text_file.close()
     try:
         with open(_wfile_name, 'rb') as file_data:
-            for minio_addr in list_minio_pods_node(best_none):
+            for minio_addr in list_stoarage_pods_node(best_none):
                 if has_pod_bucket(get_bucket_urn(urn), minio_addr):
                     client = minio_client(minio_addr)
                     file_stat = os.stat(_wfile_name)
